@@ -351,7 +351,7 @@ class Mean(Operator):
 
 
     if isinstance(vF,Field):
-      return vF/self.ax
+      return vF.mean(self.ax)
     elif isinstance(vF,VField):
       return VField([self*e for e in vF])
     else:
@@ -382,7 +382,7 @@ class Prim(Operator):
   def __call__(self,vF):
     """Call vF.vcumsum on self.Xi.
     """
-    return vF.vcumsum(self.Xi)
+    return vF.vcumsum(self.ax)
 
 
 class FieldMul(Operator):
